==> zio-aws-directconnect_2.12-5.17.158.3-sources.jar: zio/aws/directconnect/model/StopBgpFailoverTestResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class StopBgpFailoverTestResponse(
    virtualInterfaceTest: Option[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse = {
    import StopBgpFailoverTestResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
      .builder()
      .optionallyWith(virtualInterfaceTest.map(value => value.buildAwsValue()))(
        _.virtualInterfaceTest
      )
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly =
    zio.aws.directconnect.model.StopBgpFailoverTestResponse
      .wrap(buildAwsValue())
}
object StopBgpFailoverTestResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.directconnect.model.StopBgpFailoverTestResponse =
      zio.aws.directconnect.model.StopBgpFailoverTestResponse(
        virtualInterfaceTest.map(value => value.asEditable)
      )
    def virtualInterfaceTest: Option[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ]
    def getVirtualInterfaceTest: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ] = AwsError.unwrapOptionField("virtualInterfaceTest", virtualInterfaceTest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ) extends zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly {
    override val virtualInterfaceTest: Option[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ] = scala
      .Option(impl.virtualInterfaceTest())
      .map(value =>
        zio.aws.directconnect.model.VirtualInterfaceTestHistory.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ): zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-directconnect_2.12-5.17.267.6-sources.jar: zio/aws/directconnect/model/StopBgpFailoverTestResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class StopBgpFailoverTestResponse(
    virtualInterfaceTest: Optional[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse = {
    import StopBgpFailoverTestResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
      .builder()
      .optionallyWith(virtualInterfaceTest.map(value => value.buildAwsValue()))(
        _.virtualInterfaceTest
      )
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly =
    zio.aws.directconnect.model.StopBgpFailoverTestResponse
      .wrap(buildAwsValue())
}
object StopBgpFailoverTestResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.directconnect.model.StopBgpFailoverTestResponse =
      zio.aws.directconnect.model.StopBgpFailoverTestResponse(
        virtualInterfaceTest.map(value => value.asEditable)
      )
    def virtualInterfaceTest: Optional[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ]
    def getVirtualInterfaceTest: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ] = AwsError.unwrapOptionField("virtualInterfaceTest", virtualInterfaceTest)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ) extends zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly {
    override val virtualInterfaceTest: Optional[
      zio.aws.directconnect.model.VirtualInterfaceTestHistory.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.virtualInterfaceTest())
      .map(value =>
        zio.aws.directconnect.model.VirtualInterfaceTestHistory.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.StopBgpFailoverTestResponse
  ): zio.aws.directconnect.model.StopBgpFailoverTestResponse.ReadOnly =
    new Wrapper(impl)
}
